@@ -46,7 +46,9 @@ from kdp_api.model.authentication_details_authentication import AuthenticationDe
 from kdp_api.model.authentication_details_authentication_payload import AuthenticationDetailsAuthenticationPayload
 from kdp_api.model.authentication_details_user import AuthenticationDetailsUser
 from kdp_api.model.authentication_list import AuthenticationList
+from kdp_api.model.authentication_sso import AuthenticationSSO
 from kdp_api.model.batch_write_request import BatchWriteRequest
+from kdp_api.model.connection_info import ConnectionInfo
 from kdp_api.model.custom_identity_provider import CustomIdentityProvider
 from kdp_api.model.custom_identity_provider_list import CustomIdentityProviderList
 from kdp_api.model.data_source_params import DataSourceParams
@@ -62,7 +64,14 @@ from kdp_api.model.dataset_permission_list import DatasetPermissionList
 from kdp_api.model.dataset_permission_paginator import DatasetPermissionPaginator
 from kdp_api.model.dataset_permission_patch_request import DatasetPermissionPatchRequest
 from kdp_api.model.dataset_permission_update_request import DatasetPermissionUpdateRequest
+from kdp_api.model.dataset_sync import DatasetSync
+from kdp_api.model.dataset_sync_list import DatasetSyncList
+from kdp_api.model.dataset_sync_management_terminate_connection_request import DatasetSyncManagementTerminateConnectionRequest
+from kdp_api.model.dataset_sync_paginator import DatasetSyncPaginator
+from kdp_api.model.dataset_sync_patch_request import DatasetSyncPatchRequest
+from kdp_api.model.dataset_sync_update_request import DatasetSyncUpdateRequest
 from kdp_api.model.dataset_update_request import DatasetUpdateRequest
+from kdp_api.model.delete_document_by_query_request import DeleteDocumentByQueryRequest
 from kdp_api.model.delete_record_by_id_request import DeleteRecordByIdRequest
 from kdp_api.model.delete_record_by_query_request import DeleteRecordByQueryRequest
 from kdp_api.model.error_code import ErrorCode
@@ -90,6 +99,7 @@ from kdp_api.model.json_record import JsonRecord
 from kdp_api.model.keycloak_provider_configuration import KeycloakProviderConfiguration
 from kdp_api.model.koverse_document_metadata import KoverseDocumentMetadata
 from kdp_api.model.lucene_query_request import LuceneQueryRequest
+from kdp_api.model.origin_dataset_sync_create_request import OriginDatasetSyncCreateRequest
 from kdp_api.model.query import Query
 from kdp_api.model.query_datasets_summary import QueryDatasetsSummary
 from kdp_api.model.query_datasets_summary_datasets_inner import QueryDatasetsSummaryDatasetsInner
@@ -97,9 +107,11 @@ from kdp_api.model.query_datasets_summary_request import QueryDatasetsSummaryReq
 from kdp_api.model.query_document_lucene_request import QueryDocumentLuceneRequest
 from kdp_api.model.query_document_lucene_response import QueryDocumentLuceneResponse
 from kdp_api.model.query_document_lucene_response_records_inner import QueryDocumentLuceneResponseRecordsInner
+from kdp_api.model.query_document_lucene_response_schema_inner import QueryDocumentLuceneResponseSchemaInner
 from kdp_api.model.read_range_request import ReadRangeRequest
 from kdp_api.model.record_batch import RecordBatch
 from kdp_api.model.reindex_request import ReindexRequest
+from kdp_api.model.replica_dataset_sync_create_request import ReplicaDatasetSyncCreateRequest
 from kdp_api.model.security_label_info_params import SecurityLabelInfoParams
 from kdp_api.model.segment import Segment
 from kdp_api.model.segment_list import SegmentList
@@ -110,6 +122,10 @@ from kdp_api.model.source_types_list import SourceTypesList
 from kdp_api.model.split_points import SplitPoints
 from kdp_api.model.stripe_latest_charge import StripeLatestCharge
 from kdp_api.model.stripe_latest_charge1 import StripeLatestCharge1
+from kdp_api.model.sync_kafka_consumer_group_id import SyncKafkaConsumerGroupId
+from kdp_api.model.sync_setup_origin import SyncSetupOrigin
+from kdp_api.model.sync_setup_replica import SyncSetupReplica
+from kdp_api.model.terminate_connection_response import TerminateConnectionResponse
 from kdp_api.model.transfer_resource_request import TransferResourceRequest
 from kdp_api.model.transfer_resource_request_list import TransferResourceRequestList
 from kdp_api.model.upload_response import UploadResponse
